Learn R Programming

FatTailsR (version 1.7-5)

exfit0: Parameter Subsets

Description

Some vectors of parameter names to be used with parameter exfitk in functions regkienerLX(.., exfitk = ...) and fitkienerX(.., exfitk = ...) or to subset the vector (or matrix) fitk obtained after regression fitk <- regkienerLX(..)$fitk or estimation fitk <- fitkienerX(..). Visit fitkienerX for details on each parameter.

exfit0 <- c("lh", "ret")

exfit1 <- c("m", "g", "a", "k", "w", "d", "e")

exfit2 <- c("m1", "sd", "sk", "ke", "m1x", "sdx", "skx", "kex")

exfit3 <- c("q.01", "q.05", "q.95", "q.99", "ltm.025", "rtm.975")

exfit4 <- c("VaR.01", "VaR.05", "VaR.95", "VaR.99", "ES.025", "ES.975")

exfit5 <- c("c.01", "c.05", "c.95", "c.99", "h.025", "h.975")

exfit6 <- c(exfit1, exfit2, exfit3, exfit4, exfit5)

exfit7 <- c(exfit0, exfit1, exfit2, exfit3, exfit4, exfit5)

Usage

exfit0

exfit1

exfit2

exfit3

exfit4

exfit5

exfit6

exfit7

Arguments

Format

An object of class character of length 2.

Examples

Run this code
# NOT RUN {
    

require(minpack.lm)
require(timeSeries)

### Load the datasets and select one number j in 1:16
j      <- 5
DS     <- getDSdata()
(fitk  <- regkienerLX(DS[[j]])$fitk)
fitk[exfit3]
fitkienerX(DS[[j]], exfitk = exfit3)


# }

Run the code above in your browser using DataLab