Learn R Programming

FatTailsR (version 1.7-5)

laplacegaussnorm: Laplace-Gauss Normal Distribution Object

Description

An object designed after regkienerLX to summarize the information related to a given dataset when the Laplace-Gauss normal distribution is applied on it.

Usage

laplacegaussnorm(X)

Arguments

X

vector of quantiles.

Value

A list with the following data.frame:

  • dfrXPndata.frame. X = initial quantiles. Pn = estimated normal probabilites.

  • dfrXLndata.frame. X = initial quantiles. Ln = logit of estimated normal probabilites.

  • dfrXDndata.frame. X = initial quantiles. Dn = estimated normal density.

  • coefnnumeric. The mean and the standard deviation of the dataset.

  • dfrQnPndata.frame. Qn = estimated quantiles of interest. Pn = probability.

  • dfrQnPndata.frame. Qn = estimated quantiles of interest. Pn = logit of probability.

Details

This function is designed after regkienerLX to provide a similar framework.

See Also

The regression function regkienerLX.

Examples

Run this code
# NOT RUN {
    
prices2returns <- function(x) { 100*diff(log(x)) }
CAC  <- prices2returns(as.numeric(EuStockMarkets[,3])) 
lgn  <- laplacegaussnorm( CAC )
attributes(lgn)
head(lgn$dfrXPn)
head(lgn$dfrXLn)
head(lgn$dfrXDn)
lgn$coefn
lgn$dfrQnPn
lgn$dfrQnLn

# }

Run the code above in your browser using DataLab